@@ -28,15 +28,12 @@
 #define SATURDAY 6		/* Offset value; 1 Jan 1 was a Saturday */
 #define ISODATE_LENGTH 17 /* 4+2+2+1+2+2+2+1 + 1 */
 
-
 /* Number of days in a month, using 0 (Jan) to 11 (Dec). For leap years,
    add 1 to February (month 1). */
-static const int days_in_month[12] = {
+static const gint days_in_month[12] = {
 	31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31
 };
 
-
-
 /**************************************************************************
  * time_t manipulation functions.
  *
@@ -61,7 +58,7 @@ static const int days_in_month[12] = {
  * Return value: a time_t value containing @time plus the days added.
  */
 time_t
-time_add_day (time_t time, int days)
+time_add_day (time_t time, gint days)
 {
 	struct tm *tm;
 
@@ -82,7 +79,7 @@ time_add_day (time_t time, int days)
  * Return value: a time_t value containing @time plus the weeks added.
  */
 time_t
-time_add_week (time_t time, int weeks)
+time_add_week (time_t time, gint weeks)
 {
 	return time_add_day (time, weeks * 7);
 }
@@ -128,7 +125,6 @@ time_day_end (time_t t)
 	return mktime (&tm);
 }
 
-
 /**************************************************************************
  * time_t manipulation functions, using timezones in libical.
  *
@@ -137,7 +133,6 @@ time_day_end (time_t t)
  * time_t values wherever possible.
  **************************************************************************/
 
-
 /**
  * time_add_day_with_zone:
  * @time: A time_t value.
@@ -153,7 +148,7 @@ time_day_end (time_t t)
  * Return value: a time_t value containing @time plus the days added.
  */
 time_t
-time_add_day_with_zone (time_t time, int days, icaltimezone *zone)
+time_add_day_with_zone (time_t time, gint days, icaltimezone *zone)
 {
 	struct icaltimetype tt;
 
@@ -167,7 +162,6 @@ time_add_day_with_zone (time_t time, int days, icaltimezone *zone)
 	return icaltime_as_timet_with_zone (tt, zone);
 }
 
-
 /**
  * time_add_week_with_zone:
  * @time: A time_t value.
@@ -183,12 +177,11 @@ time_add_day_with_zone (time_t time, int days, icaltimezone *zone)
  * Return value: a time_t value containing @time plus the weeks added.
  */
 time_t
-time_add_week_with_zone (time_t time, int weeks, icaltimezone *zone)
+time_add_week_with_zone (time_t time, gint weeks, icaltimezone *zone)
 {
 	return time_add_day_with_zone (time, weeks * 7, zone);
 }
 
-
 /**
  * time_add_month_with_zone:
  * @time: A time_t value.
@@ -209,10 +202,10 @@ time_add_week_with_zone (time_t time, int weeks, icaltimezone *zone)
  * Return value: a time_t value containing @time plus the months added.
  */
 time_t
-time_add_month_with_zone (time_t time, int months, icaltimezone *zone)
+time_add_month_with_zone (time_t time, gint months, icaltimezone *zone)
 {
 	struct icaltimetype tt;
-	int day, days_in_month;
+	gint day, days_in_month;
 
 	/* Convert to an icaltimetype. */
 	tt = icaltime_from_timet_with_zone (time, FALSE, zone);
@@ -239,7 +232,6 @@ time_add_month_with_zone (time_t time, int months, icaltimezone *zone)
 	return icaltime_as_timet_with_zone (tt, zone);
 }
 
-
 /**
  * time_year_begin_with_zone:
  * @time: A time_t value.
@@ -272,7 +264,6 @@ time_year_begin_with_zone (time_t time, icaltimezone *zone)
 	return icaltime_as_timet_with_zone (tt, zone);
 }
 
-
 /**
  * time_month_begin_with_zone:
  * @time: A time_t value.
@@ -304,7 +295,6 @@ time_month_begin_with_zone (time_t time, icaltimezone *zone)
 	return icaltime_as_timet_with_zone (tt, zone);
 }
 
-
 /**
  * time_week_begin_with_zone:
  * @time: A time_t value.
@@ -321,10 +311,10 @@ time_month_begin_with_zone (time_t time, icaltimezone *zone)
  * Return value: the beginning of the week.
  */
 time_t
-time_week_begin_with_zone (time_t time, int week_start_day, icaltimezone *zone)
+time_week_begin_with_zone (time_t time, gint week_start_day, icaltimezone *zone)
 {
 	struct icaltimetype tt;
-	int weekday, offset;
+	gint weekday, offset;
 
 	/* Convert to an icaltimetype. */
 	tt = icaltime_from_timet_with_zone (time, FALSE, zone);
@@ -348,7 +338,6 @@ time_week_begin_with_zone (time_t time, int week_start_day, icaltimezone *zone)
 	return icaltime_as_timet_with_zone (tt, zone);
 }
 
-
 /**
  * time_day_begin_with_zone:
  * @time: A time_t value.
@@ -379,7 +368,6 @@ time_day_begin_with_zone (time_t time, icaltimezone *zone)
 	return icaltime_as_timet_with_zone (tt, zone);
 }
 
-
 /**
  * time_day_end_with_zone:
  * @time: A time_t value.
@@ -438,12 +426,10 @@ time_to_gdate_with_zone (GDate *date, time_t time, icaltimezone *zone)
 	g_date_set_dmy (date, tt.day, tt.month, tt.year);
 }
 
-
 /**************************************************************************
  * General time functions.
  **************************************************************************/
 
-
 /**
  * time_days_in_month:
  * @year: The year.
@@ -454,10 +440,10 @@ time_to_gdate_with_zone (GDate *date, time_t time, icaltimezone *zone)
  *
  * Return value: number of days in the given month/year.
  */
-int
-time_days_in_month (int year, int month)
+gint
+time_days_in_month (gint year, gint month)
 {
-	int days;
+	gint days;
 
 	g_return_val_if_fail (year >= 1900, 0);
 	g_return_val_if_fail ((month >= 0) && (month < 12), 0);
@@ -469,7 +455,6 @@ time_days_in_month (int year, int month)
 	return days;
 }
 
-
 /**
  * time_day_of_year:
  * @day: The day.
@@ -481,10 +466,10 @@ time_days_in_month (int year, int month)
  *
  * Return value: the day of the year.
  */
-int
-time_day_of_year (int day, int month, int year)
+gint
+time_day_of_year (gint day, gint month, gint year)
 {
-	int i;
+	gint i;
 
 	for (i = 0; i < month; i++) {
 		day += days_in_month[i];
@@ -496,7 +481,6 @@ time_day_of_year (int day, int month, int year)
 	return day;
 }
 
-
 /**
  * time_day_of_week:
  * @day: The day.
@@ -509,10 +493,10 @@ time_day_of_year (int day, int month, int year)
  *
  * Return value: the day of the week for the given date.
  */
-int
-time_day_of_week (int day, int month, int year)
+gint
+time_day_of_week (gint day, gint month, gint year)
 {
-	int n;
+	gint n;
 
 	n = (year - 1) * 365 + time_leap_years_up_to (year - 1)
 	  + time_day_of_year (day, month, year);
@@ -526,7 +510,6 @@ time_day_of_week (int day, int month, int year)
 	return THURSDAY;
 }
 
-
 /**
  * time_is_leap_year:
  * @year: The year.
@@ -537,7 +520,7 @@ time_day_of_week (int day, int month, int year)
  * Return value: TRUE if the year is leap, FALSE if not.
  */
 gboolean
-time_is_leap_year (int year)
+time_is_leap_year (gint year)
 {
 	if (year <= 1752)
 		return !(year % 4);
@@ -545,7 +528,6 @@ time_is_leap_year (int year)
 		return (!(year % 4) && (year % 100)) || !(year % 400);
 }
 
-
 /**
  * time_leap_years_up_to:
  * @year: The year.
@@ -555,8 +537,8 @@ time_is_leap_year (int year)
  *
  * Return value: number of leap years.
  */
-int
-time_leap_years_up_to (int year)
+gint
+time_leap_years_up_to (gint year)
 {
 	/* There is normally a leap year every 4 years, except at the turn of
 	   centuries since 1700. But there is a leap year on centuries since 1700
@@ -566,7 +548,6 @@ time_leap_years_up_to (int year)
 		+ ((year > 1600) ? ((year - 1600) / 400) : 0));
 }
 
-
 /**
  * isodate_from_time_t:
  * @t: A time value.
@@ -575,12 +556,12 @@ time_leap_years_up_to (int year)
  *
  * Return value: String with the ISO 8601 representation of the UTC time.
  **/
-char *
+gchar *
 isodate_from_time_t (time_t t)
 {
 	gchar *ret;
 	struct tm stm;
-	const char fmt[] = "%04d%02d%02dT%02d%02d%02dZ";
+	const gchar fmt[] = "%04d%02d%02dT%02d%02d%02dZ";
 
 	gmtime_r (&t, &stm);
 	ret = g_malloc (ISODATE_LENGTH);
@@ -599,11 +580,11 @@ isodate_from_time_t (time_t t)
  * Note that we only allow UTC times at present.
  **/
 time_t
-time_from_isodate (const char *str)
+time_from_isodate (const gchar *str)
 {
 	struct icaltimetype tt = icaltime_null_time ();
 	icaltimezone *utc_zone;
-	int len, i;
+	gint len, i;
 
 	g_return_val_if_fail (str != NULL, -1);
 
