@@ -37,7 +37,6 @@
 #include <glib/gstdio.h>
 #include <glib/gi18n-lib.h>
 
-#include <libedataserver/e-data-server-util.h>
 #include "camel-data-cache.h"
 #include "camel-exception.h"
 #include "camel-stream-fs.h"
@@ -203,7 +202,7 @@ data_cache_expire(CamelDataCache *cdc, const gchar *path, const gchar *keep, tim
 		return;
 
 	s = g_string_new("");
-	while ( (dname = g_dir_read_name(dir)) ) {
+	while ((dname = g_dir_read_name(dir))) {
 		if (strcmp(dname, keep) == 0)
 			continue;
 
@@ -254,7 +253,7 @@ data_cache_path(CamelDataCache *cdc, gint create, const gchar *path, const gchar
 		dd(printf("Checking expire cycle time on dir '%s'\n", dir));
 
 		/* This has a race, but at worst we re-run an expire cycle which is safe */
-		now = time(0);
+		now = time(NULL);
 		if (cdc->priv->expire_last[hash] + CAMEL_DATA_CACHE_CYCLE_TIME < now) {
 			cdc->priv->expire_last[hash] = now;
 			data_cache_expire(cdc, dir, key, now);
