@@ -30,12 +30,13 @@
 
 /**
  * camel_dlist_init:
- * @v: 
- * 
+ * @v:
+ *
  * Initialise a double-linked list header.  All list headers must be
  * initialised before use.
  **/
-void camel_dlist_init(CamelDList *v)
+void
+camel_dlist_init (CamelDList *v)
 {
         v->head = (CamelDListNode *)&v->tail;
         v->tail = NULL;
@@ -46,12 +47,13 @@ void camel_dlist_init(CamelDList *v)
  * camel_dlist_addhead:
  * @l: An initialised list header.
  * @n: A node, the next and prev pointers will be overwritten.
- * 
+ *
  * Add the list node @n to the head (start) of the list @l.
- * 
+ *
  * Return value: @n.
  **/
-CamelDListNode *camel_dlist_addhead(CamelDList *l, CamelDListNode *n)
+CamelDListNode *
+camel_dlist_addhead (CamelDList *l, CamelDListNode *n)
 {
         n->next = l->head;
         n->prev = (CamelDListNode *)&l->head;
@@ -64,12 +66,13 @@ CamelDListNode *camel_dlist_addhead(CamelDList *l, CamelDListNode *n)
  * camel_dlist_addtail:
  * @l: An intialised list header.
  * @n: A node, the next and prev pointers will be overwritten.
- * 
+ *
  * Add the list onde @n to the tail (end) of the list @l.
- * 
+ *
  * Return value: @n.
  **/
-CamelDListNode *camel_dlist_addtail(CamelDList *l, CamelDListNode *n)
+CamelDListNode *
+camel_dlist_addtail (CamelDList *l, CamelDListNode *n)
 {
         n->next = (CamelDListNode *)&l->tail;
         n->prev = l->tailpred;
@@ -81,12 +84,13 @@ CamelDListNode *camel_dlist_addtail(CamelDList *l, CamelDListNode *n)
 /**
  * camel_dlist_remove:
  * @n: A node which is part of a list.
- * 
+ *
  * Remove @n from the list it's in.  @n must belong to a list.
- * 
+ *
  * Return value: @n.
  **/
-CamelDListNode *camel_dlist_remove(CamelDListNode *n)
+CamelDListNode *
+camel_dlist_remove (CamelDListNode *n)
 {
         n->next->prev = n->prev;
         n->prev->next = n->next;
@@ -96,13 +100,14 @@ CamelDListNode *camel_dlist_remove(CamelDListNode *n)
 /**
  * camel_dlist_remhead:
  * @l: An initialised list, maybe containing items.
- * 
+ *
  * Remove the head node (start) of the list.
- * 
+ *
  * xReturn value: The previously first-node in the list, or NULLif @l
  * is an empty list.
  **/
-CamelDListNode *camel_dlist_remhead(CamelDList *l)
+CamelDListNode *
+camel_dlist_remhead (CamelDList *l)
 {
 	CamelDListNode *n, *nn;
 
@@ -119,13 +124,14 @@ CamelDListNode *camel_dlist_remhead(CamelDList *l)
 /**
  * camel_dlist_remtail:
  * @l: An initialised list, maybe containing items.
- * 
+ *
  * Remove the last node in the list.
- * 
+ *
  * Return value: The previously last-node in the list, or NULL if @l
  * is an empty list.
  **/
-CamelDListNode *camel_dlist_remtail(CamelDList *l)
+CamelDListNode *
+camel_dlist_remtail (CamelDList *l)
 {
 	CamelDListNode *n, *np;
 
@@ -142,12 +148,13 @@ CamelDListNode *camel_dlist_remtail(CamelDList *l)
 /**
  * camel_dlist_empty:
  * @l: An initialised list header.
- * 
+ *
  * Returns %TRUE if @l is an empty list.
- * 
+ *
  * Return value: %TRUE if @l is an empty list, %FALSE otherwise.
  **/
-int camel_dlist_empty(CamelDList *l)
+gint
+camel_dlist_empty (CamelDList *l)
 {
 	return (l->head == (CamelDListNode *)&l->tail);
 }
@@ -155,15 +162,16 @@ int camel_dlist_empty(CamelDList *l)
 /**
  * camel_dlist_length:
  * @l: An initialised list header.
- * 
+ *
  * Returns the number of nodes in the list @l.
- * 
+ *
  * Return value: The number of nodes.
  **/
-int camel_dlist_length(CamelDList *l)
+gint
+camel_dlist_length (CamelDList *l)
 {
 	CamelDListNode *n, *nn;
-	int count = 0;
+	gint count = 0;
 
 	n = l->head;
 	nn = n->next;
@@ -178,12 +186,14 @@ int camel_dlist_length(CamelDList *l)
 
 /* This is just for orthogonal completeness */
 
-void camel_slist_init(CamelSList *v)
+void
+camel_slist_init (CamelSList *v)
 {
 	v->head = NULL;
 }
 
-CamelSListNode *camel_slist_addhead(CamelSList *l, CamelSListNode *n)
+CamelSListNode *
+camel_slist_addhead (CamelSList *l, CamelSListNode *n)
 {
         n->next = l->head;
 	l->head = n;
@@ -191,7 +201,8 @@ CamelSListNode *camel_slist_addhead(CamelSList *l, CamelSListNode *n)
 	return n;
 }
 
-CamelSListNode *camel_slist_addtail(CamelSList *l, CamelSListNode *n)
+CamelSListNode *
+camel_slist_addtail (CamelSList *l, CamelSListNode *n)
 {
 	CamelSListNode *p;
 
@@ -204,12 +215,13 @@ CamelSListNode *camel_slist_addtail(CamelSList *l, CamelSListNode *n)
         return n;
 }
 
-CamelSListNode *camel_slist_remove(CamelSList *l, CamelSListNode *n)
+CamelSListNode *
+camel_slist_remove (CamelSList *l, CamelSListNode *n)
 {
 	CamelSListNode *p, *q;
 
 	p = (CamelSListNode *)l;
-	while ( (q = p->next) ) {
+	while ((q = p->next)) {
 		if (q == n) {
 			p->next = n->next;
 			return n;
@@ -222,7 +234,8 @@ CamelSListNode *camel_slist_remove(CamelSList *l, CamelSListNode *n)
 	return NULL;
 }
 
-CamelSListNode *camel_slist_remhead(CamelSList *l)
+CamelSListNode *
+camel_slist_remhead (CamelSList *l)
 {
 	CamelSListNode *n;
 
@@ -233,7 +246,8 @@ CamelSListNode *camel_slist_remhead(CamelSList *l)
 	return n;
 }
 
-CamelSListNode *camel_slist_remtail(CamelSList *l)
+CamelSListNode *
+camel_slist_remtail (CamelSList *l)
 {
 	CamelSListNode *n, *p;
 
@@ -250,15 +264,17 @@ CamelSListNode *camel_slist_remtail(CamelSList *l)
 	return n;
 }
 
-int camel_slist_empty(CamelSList *l)
+gint
+camel_slist_empty (CamelSList *l)
 {
 	return (l->head == NULL);
 }
 
-int camel_slist_length(CamelSList *l)
+gint
+camel_slist_length (CamelSList *l)
 {
 	CamelSListNode *n;
-	int count = 0;
+	gint count = 0;
 
 	n = l->head;
 	while (n) {
