@@ -1,15 +1,15 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* camel-store.c : Abstract class for an email store */
 
-/* 
+/*
  * Authors:
  *  Bertrand Guiheneuf <bertrand@helixcode.com>
  *  Dan Winship <danw@ximian.com>
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -43,7 +43,7 @@
 #include "camel-store.h"
 #include "camel-vtrash-folder.h"
 
-#define d(x) 
+#define d(x)
 #define w(x)
 
 static CamelServiceClass *parent_class = NULL;
@@ -51,7 +51,7 @@ static CamelServiceClass *parent_class = NULL;
 /* Returns the class for a CamelStore */
 #define CS_CLASS(so) ((CamelStoreClass *)((CamelObject *)(so))->klass)
 
-static CamelFolder *get_folder (CamelStore *store, const char *folder_name,
+static CamelFolder *get_folder (CamelStore *store, const gchar *folder_name,
 				guint32 flags, CamelException *ex);
 static CamelFolder *get_inbox (CamelStore *store, CamelException *ex);
 
@@ -59,22 +59,22 @@ static CamelFolder *get_trash (CamelStore *store, CamelException *ex);
 static CamelFolder *get_junk (CamelStore *store, CamelException *ex);
 
 static CamelFolderInfo *create_folder (CamelStore *store,
-				       const char *parent_name,
-				       const char *folder_name,
+				       const gchar *parent_name,
+				       const gchar *folder_name,
 				       CamelException *ex);
-static void delete_folder (CamelStore *store, const char *folder_name,
+static void delete_folder (CamelStore *store, const gchar *folder_name,
 			   CamelException *ex);
-static void rename_folder (CamelStore *store, const char *old_name,
-			   const char *new_name, CamelException *ex);
+static void rename_folder (CamelStore *store, const gchar *old_name,
+			   const gchar *new_name, CamelException *ex);
 
-static void store_sync (CamelStore *store, int expunge, CamelException *ex);
-static CamelFolderInfo *get_folder_info (CamelStore *store, const char *top,
+static void store_sync (CamelStore *store, gint expunge, CamelException *ex);
+static CamelFolderInfo *get_folder_info (CamelStore *store, const gchar *top,
 					 guint32 flags, CamelException *ex);
 static void free_folder_info (CamelStore *store, CamelFolderInfo *tree);
 
-static gboolean folder_subscribed (CamelStore *store, const char *folder_name);
-static void subscribe_folder (CamelStore *store, const char *folder_name, CamelException *ex);
-static void unsubscribe_folder (CamelStore *store, const char *folder_name, CamelException *ex);
+static gboolean folder_subscribed (CamelStore *store, const gchar *folder_name);
+static void subscribe_folder (CamelStore *store, const gchar *folder_name, CamelException *ex);
+static void unsubscribe_folder (CamelStore *store, const gchar *folder_name, CamelException *ex);
 
 static void noop (CamelStore *store, CamelException *ex);
 
@@ -84,17 +84,17 @@ static void construct (CamelService *service, CamelSession *session,
 		       CamelProvider *provider, CamelURL *url,
 		       CamelException *ex);
 
-static int store_setv (CamelObject *object, CamelException *ex, CamelArgV *args);
-static int store_getv (CamelObject *object, CamelException *ex, CamelArgGetV *args);
+static gint store_setv (CamelObject *object, CamelException *ex, CamelArgV *args);
+static gint store_getv (CamelObject *object, CamelException *ex, CamelArgGetV *args);
 
 static void
 camel_store_class_init (CamelStoreClass *camel_store_class)
 {
 	CamelObjectClass *camel_object_class = CAMEL_OBJECT_CLASS (camel_store_class);
 	CamelServiceClass *camel_service_class = CAMEL_SERVICE_CLASS(camel_store_class);
-	
+
 	parent_class = CAMEL_SERVICE_CLASS (camel_type_get_global_classfuncs (camel_service_get_type ()));
-	
+
 	/* virtual method definition */
 	camel_store_class->hash_folder_name = g_str_hash;
 	camel_store_class->compare_folder_name = g_str_equal;
@@ -129,7 +129,7 @@ camel_store_class_init (CamelStoreClass *camel_store_class)
 }
 
 static void
-camel_store_init (void *o)
+camel_store_init (gpointer o)
 {
 	CamelStore *store = o;
 	CamelStoreClass *store_class = (CamelStoreClass *)CAMEL_OBJECT_GET_CLASS (o);
@@ -140,7 +140,7 @@ camel_store_init (void *o)
 						      (CamelCopyFunc)g_strdup, g_free);
 	} else
 		store->folders = NULL;
-	
+
 	/* set vtrash and vjunk on by default */
 	store->flags = CAMEL_STORE_VTRASH | CAMEL_STORE_VJUNK;
 	store->mode = CAMEL_STORE_READ|CAMEL_STORE_WRITE;
@@ -157,7 +157,7 @@ camel_store_finalize (CamelObject *object)
 	d(printf ("\ncamel_store_finalize called \n"));
 	if (store->folders)
 		camel_object_bag_destroy(store->folders);
-	
+
 	g_static_rec_mutex_free (&store->priv->folder_lock);
 
 	if (store->cdb_r) {
@@ -173,7 +173,6 @@ camel_store_finalize (CamelObject *object)
 	g_free (store->priv);
 }
 
-
 CamelType
 camel_store_get_type (void)
 {
@@ -192,14 +191,14 @@ camel_store_get_type (void)
 	return camel_store_type;
 }
 
-static int
+static gint
 store_setv (CamelObject *object, CamelException *ex, CamelArgV *args)
 {
 	/* CamelStore doesn't currently have anything to set */
 	return CAMEL_OBJECT_CLASS (parent_class)->setv (object, ex, args);
 }
 
-static int
+static gint
 store_getv (CamelObject *object, CamelException *ex, CamelArgGetV *args)
 {
 	/* CamelStore doesn't currently have anything to get */
@@ -212,7 +211,7 @@ construct (CamelService *service, CamelSession *session,
 	   CamelException *ex)
 {
 	CamelStore *store = CAMEL_STORE(service);
-	char *store_db_path, *store_path = NULL;
+	gchar *store_db_path, *store_path = NULL;
 
 	parent_class->construct(service, session, provider, url, ex);
 	if (camel_exception_is_set (ex))
@@ -239,11 +238,11 @@ construct (CamelService *service, CamelSession *session,
 	if (camel_debug("sqlite"))
 		printf("store_db_path %s\n", store_db_path);
 	if (camel_exception_is_set (ex)) {
-		char *store_path;
-		
+		gchar *store_path;
+
 		if (camel_debug("sqlite"))
 			g_print ("Failure for store_db_path : [%s]\n", store_db_path);
-		g_free (store_db_path);		
+		g_free (store_db_path);
 
 		store_path =  camel_session_get_storage_path (session, service, ex);
 		store_db_path = g_build_filename (store_path, CAMEL_DB_FILE, NULL);
@@ -261,8 +260,9 @@ construct (CamelService *service, CamelSession *session,
 
 	if (camel_db_create_folders_table (store->cdb_r, ex))
 		g_warning ("something went wrong terribly during db creation \n");
-	else
+	else {
 		d(printf ("folders table successfully created \n"));
+	}
 
 	if (camel_exception_is_set (ex))
 		return;
@@ -274,18 +274,18 @@ construct (CamelService *service, CamelSession *session,
 }
 
 static CamelFolder *
-get_folder (CamelStore *store, const char *folder_name, guint32 flags, CamelException *ex)
+get_folder (CamelStore *store, const gchar *folder_name, guint32 flags, CamelException *ex)
 {
 	w(g_warning ("CamelStore::get_folder not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
-	
+
 	camel_exception_setv (ex, CAMEL_EXCEPTION_STORE_INVALID,
 			      _("Cannot get folder: Invalid operation on this store"));
-	
+
 	return NULL;
 }
 
-/** 
+/**
  * camel_store_get_folder:
  * @store: a #CamelStore object
  * @folder_name: name of the folder to get
@@ -297,7 +297,7 @@ get_folder (CamelStore *store, const char *folder_name, guint32 flags, CamelExce
  * Returns: the folder corresponding to the path @folder_name or %NULL.
  **/
 CamelFolder *
-camel_store_get_folder (CamelStore *store, const char *folder_name, guint32 flags, CamelException *ex)
+camel_store_get_folder (CamelStore *store, const gchar *folder_name, guint32 flags, CamelException *ex)
 {
 	CamelFolder *folder = NULL;
 
@@ -325,13 +325,13 @@ camel_store_get_folder (CamelStore *store, const char *folder_name, guint32 flag
 
 		if (flags & CAMEL_STORE_IS_MIGRATING) {
 				if ((store->flags & CAMEL_STORE_VTRASH) && strcmp(folder_name, CAMEL_VTRASH_NAME) == 0) {
-						if (store->folders) 
+						if (store->folders)
 								camel_object_bag_abort(store->folders, folder_name);
 						return NULL;
 				}
 
 				if ((store->flags & CAMEL_STORE_VJUNK) && strcmp(folder_name, CAMEL_VJUNK_NAME) == 0) {
-						if (store->folders) 
+						if (store->folders)
 								camel_object_bag_abort(store->folders, folder_name);
 						return NULL;
 				}
@@ -345,7 +345,7 @@ camel_store_get_folder (CamelStore *store, const char *folder_name, guint32 flag
 			folder = CS_CLASS (store)->get_folder(store, folder_name, flags, ex);
 			if (folder) {
 				CamelVeeFolder *vfolder;
-				
+
 				if ((store->flags & CAMEL_STORE_VTRASH)
 				    && (vfolder = camel_object_bag_get(store->folders, CAMEL_VTRASH_NAME))) {
 					camel_vee_folder_add_folder(vfolder, folder);
@@ -372,9 +372,9 @@ camel_store_get_folder (CamelStore *store, const char *folder_name, guint32 flag
 	}
 
 	if (camel_debug_start(":store")) {
-		char *u = camel_url_to_string(((CamelService *)store)->url, CAMEL_URL_HIDE_PASSWORD);
+		gchar *u = camel_url_to_string(((CamelService *)store)->url, CAMEL_URL_HIDE_PASSWORD);
 
-		printf("CamelStore('%s'):get_folder('%s', %u) = %p\n", u, folder_name, flags, (void *) folder);
+		printf("CamelStore('%s'):get_folder('%s', %u) = %p\n", u, folder_name, flags, (gpointer) folder);
 		if (ex && ex->id)
 			printf("  failed: '%s'\n", ex->desc);
 		g_free(u);
@@ -385,25 +385,25 @@ camel_store_get_folder (CamelStore *store, const char *folder_name, guint32 flag
 }
 
 static CamelFolderInfo *
-create_folder (CamelStore *store, const char *parent_name,
-	       const char *folder_name, CamelException *ex)
+create_folder (CamelStore *store, const gchar *parent_name,
+	       const gchar *folder_name, CamelException *ex)
 {
 	w(g_warning ("CamelStore::create_folder not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
-	
+
 	camel_exception_setv (ex, CAMEL_EXCEPTION_STORE_INVALID,
 			      _("Cannot create folder: Invalid operation on this store"));
-	
+
 	return NULL;
 }
 
-/** 
+/**
  * camel_store_create_folder:
  * @store: a #CamelStore object
  * @parent_name: name of the new folder's parent, or %NULL
  * @folder_name: name of the folder to create
  * @ex: a #CamelException
- * 
+ *
  * Creates a new folder as a child of an existing folder.
  * @parent_name can be %NULL to create a new top-level folder.
  *
@@ -411,8 +411,8 @@ create_folder (CamelStore *store, const char *parent_name,
  * free with #camel_store_free_folder_info, or %NULL.
  **/
 CamelFolderInfo *
-camel_store_create_folder (CamelStore *store, const char *parent_name,
-			   const char *folder_name, CamelException *ex)
+camel_store_create_folder (CamelStore *store, const gchar *parent_name,
+			   const gchar *folder_name, CamelException *ex)
 {
 	CamelFolderInfo *fi;
 
@@ -433,14 +433,14 @@ camel_store_create_folder (CamelStore *store, const char *parent_name,
 
 /* deletes folder/removes it from the folder cache, if it's there */
 static void
-cs_delete_cached_folder(CamelStore *store, const char *folder_name)
+cs_delete_cached_folder(CamelStore *store, const gchar *folder_name)
 {
 	CamelFolder *folder;
 
 	if (store->folders
 	    && (folder = camel_object_bag_get(store->folders, folder_name))) {
 		CamelVeeFolder *vfolder;
-			
+
 		if ((store->flags & CAMEL_STORE_VTRASH)
 		    && (vfolder = camel_object_bag_get(store->folders, CAMEL_VTRASH_NAME))) {
 			camel_vee_folder_remove_folder(vfolder, folder);
@@ -461,22 +461,22 @@ cs_delete_cached_folder(CamelStore *store, const char *folder_name)
 }
 
 static void
-delete_folder (CamelStore *store, const char *folder_name, CamelException *ex)
+delete_folder (CamelStore *store, const gchar *folder_name, CamelException *ex)
 {
 	w(g_warning ("CamelStore::delete_folder not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
 }
 
-/** 
+/**
  * camel_store_delete_folder:
  * @store: a #CamelStore object
  * @folder_name: name of the folder to delete
  * @ex: a #CamelException
- * 
+ *
  * Deletes the named folder. The folder must be empty.
  **/
 void
-camel_store_delete_folder (CamelStore *store, const char *folder_name, CamelException *ex)
+camel_store_delete_folder (CamelStore *store, const gchar *folder_name, CamelException *ex)
 {
 	CamelException local;
 
@@ -505,12 +505,12 @@ camel_store_delete_folder (CamelStore *store, const char *folder_name, CamelExce
 		camel_exception_xfer(ex, &local);
 		printf("excep: %s\n", camel_exception_get_description (ex));
 	}
-	
+
 	CAMEL_STORE_UNLOCK(store, folder_lock);
 }
 
 static void
-rename_folder (CamelStore *store, const char *old_name, const char *new_name, CamelException *ex)
+rename_folder (CamelStore *store, const gchar *old_name, const gchar *new_name, CamelException *ex)
 {
 	w(g_warning ("CamelStore::rename_folder not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
@@ -522,16 +522,16 @@ rename_folder (CamelStore *store, const char *old_name, const char *new_name, Ca
  * @old_namein: the current name of the folder
  * @new_name: the new name of the folder
  * @ex: a #CamelException
- * 
+ *
  * Rename a named folder to a new name.
  **/
 void
-camel_store_rename_folder (CamelStore *store, const char *old_namein, const char *new_name, CamelException *ex)
+camel_store_rename_folder (CamelStore *store, const gchar *old_namein, const gchar *new_name, CamelException *ex)
 {
 	CamelFolder *folder;
-	int i, oldlen, namelen;
+	gint i, oldlen, namelen;
 	GPtrArray *folders = NULL;
-	char *old_name;
+	gchar *old_name;
 
 	d(printf("store rename folder %s '%s' '%s'\n", ((CamelService *)store)->url->protocol, old_name, new_name));
 
@@ -577,40 +577,42 @@ camel_store_rename_folder (CamelStore *store, const char *old_namein, const char
 	CS_CLASS (store)->rename_folder (store, old_name, new_name, ex);
 
 	/* If it worked, update all open folders/unlock them */
-	if (folders && !camel_exception_is_set(ex)) {
-		guint32 flags = CAMEL_STORE_FOLDER_INFO_RECURSIVE;
-		CamelRenameInfo reninfo;
+	if (folders) {
+		if (!camel_exception_is_set(ex)) {
+			guint32 flags = CAMEL_STORE_FOLDER_INFO_RECURSIVE;
+			CamelRenameInfo reninfo;
 
-		for (i=0;i<folders->len;i++) {
-			char *new;
+			for (i=0;i<folders->len;i++) {
+				gchar *new;
 
-			folder = folders->pdata[i];
+				folder = folders->pdata[i];
 
-			new = g_strdup_printf("%s%s", new_name, folder->full_name+strlen(old_name));
-			camel_object_bag_rekey(store->folders, folder, new);
-			camel_folder_rename(folder, new);
-			g_free(new);
+				new = g_strdup_printf("%s%s", new_name, folder->full_name+strlen(old_name));
+				camel_object_bag_rekey(store->folders, folder, new);
+				camel_folder_rename(folder, new);
+				g_free(new);
 
-			CAMEL_FOLDER_REC_UNLOCK(folder, lock);
-			camel_object_unref(folder);
-		}
+				CAMEL_FOLDER_REC_UNLOCK(folder, lock);
+				camel_object_unref(folder);
+			}
 
-		/* Emit renamed signal */
-		if (store->flags & CAMEL_STORE_SUBSCRIPTIONS)
-			flags |= CAMEL_STORE_FOLDER_INFO_SUBSCRIBED;
-		
-		reninfo.old_base = (char *)old_name;
-		reninfo.new = ((CamelStoreClass *)((CamelObject *)store)->klass)->get_folder_info(store, new_name, flags, ex);
-		if (reninfo.new != NULL) {
-			camel_object_trigger_event (store, "folder_renamed", &reninfo);
-			((CamelStoreClass *)((CamelObject *)store)->klass)->free_folder_info(store, reninfo.new);
-		}
-	} else {
-		/* Failed, just unlock our folders for re-use */
-		for (i=0;i<folders->len;i++) {
-			folder = folders->pdata[i];
-			CAMEL_FOLDER_REC_UNLOCK(folder, lock);
-			camel_object_unref(folder);
+			/* Emit renamed signal */
+			if (store->flags & CAMEL_STORE_SUBSCRIPTIONS)
+				flags |= CAMEL_STORE_FOLDER_INFO_SUBSCRIBED;
+
+			reninfo.old_base = (gchar *)old_name;
+			reninfo.new = ((CamelStoreClass *)((CamelObject *)store)->klass)->get_folder_info(store, new_name, flags, ex);
+			if (reninfo.new != NULL) {
+				camel_object_trigger_event (store, "folder_renamed", &reninfo);
+				((CamelStoreClass *)((CamelObject *)store)->klass)->free_folder_info(store, reninfo.new);
+			}
+		} else {
+			/* Failed, just unlock our folders for re-use */
+			for (i=0;i<folders->len;i++) {
+				folder = folders->pdata[i];
+				CAMEL_FOLDER_REC_UNLOCK(folder, lock);
+				camel_object_unref(folder);
+			}
 		}
 	}
 
@@ -620,7 +622,6 @@ camel_store_rename_folder (CamelStore *store, const char *old_namein, const char
 	g_free(old_name);
 }
 
-
 static CamelFolder *
 get_inbox (CamelStore *store, CamelException *ex)
 {
@@ -630,7 +631,7 @@ get_inbox (CamelStore *store, CamelException *ex)
 	return CS_CLASS (store)->get_folder (store, "inbox", 0, ex);
 }
 
-/** 
+/**
  * camel_store_get_inbox:
  * @store: a #CamelStore object
  * @ex: a #CamelException
@@ -655,7 +656,7 @@ get_special(CamelStore *store, camel_vtrash_folder_t type)
 {
 	CamelFolder *folder;
 	GPtrArray *folders;
-	int i;
+	gint i;
 
 	folder = camel_vtrash_folder_new(store, type);
 	folders = camel_object_bag_list(store->folders);
@@ -681,7 +682,7 @@ get_junk(CamelStore *store, CamelException *ex)
 	return get_special(store, CAMEL_VTRASH_FOLDER_JUNK);
 }
 
-/** 
+/**
  * camel_store_get_trash:
  * @store: a #CamelStore object
  * @ex: a #CamelException
@@ -698,7 +699,7 @@ camel_store_get_trash (CamelStore *store, CamelException *ex)
 		return camel_store_get_folder(store, CAMEL_VTRASH_NAME, 0, ex);
 }
 
-/** 
+/**
  * camel_store_get_junk:
  * @store: a #CamelStore object
  * @ex: a #CamelException
@@ -727,13 +728,13 @@ ignore_no_such_table_exception (CamelException *ex)
 }
 
 static void
-store_sync (CamelStore *store, int expunge, CamelException *ex)
+store_sync (CamelStore *store, gint expunge, CamelException *ex)
 {
 	if (store->folders) {
 		GPtrArray *folders;
 		CamelFolder *folder;
 		CamelException x;
-		int i;
+		gint i;
 
 		/* we don't sync any vFolders, that is used to update certain vfolder queries mainly,
 		   and we're really only interested in storing/expunging the physical mails */
@@ -764,7 +765,7 @@ store_sync (CamelStore *store, int expunge, CamelException *ex)
  * folders with the real store.
  **/
 void
-camel_store_sync(CamelStore *store, int expunge, CamelException *ex)
+camel_store_sync(CamelStore *store, gint expunge, CamelException *ex)
 {
 	g_return_if_fail (CAMEL_IS_STORE (store));
 
@@ -772,30 +773,30 @@ camel_store_sync(CamelStore *store, int expunge, CamelException *ex)
 }
 
 static CamelFolderInfo *
-get_folder_info (CamelStore *store, const char *top, guint32 flags, CamelException *ex)
+get_folder_info (CamelStore *store, const gchar *top, guint32 flags, CamelException *ex)
 {
 	w(g_warning ("CamelStore::get_folder_info not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
-	
+
 	return NULL;
 }
 
 static void
-add_special_info (CamelStore *store, CamelFolderInfo *info, const char *name, const char *translated, gboolean unread_count, guint32 flags)
+add_special_info (CamelStore *store, CamelFolderInfo *info, const gchar *name, const gchar *translated, gboolean unread_count, guint32 flags)
 {
 	CamelFolderInfo *fi, *vinfo, *parent;
-	char *uri, *path;
+	gchar *uri, *path;
 	CamelURL *url;
-	
+
 	g_return_if_fail (info != NULL);
-	
+
 	parent = NULL;
 	for (fi = info; fi; fi = fi->next) {
 		if (!strcmp (fi->full_name, name))
 			break;
 		parent = fi;
 	}
-	
+
 	/* create our vTrash/vJunk URL */
 	url = camel_url_new (info->uri, NULL);
 	if (((CamelService *) store)->provider->url_flags & CAMEL_URL_FRAGMENT_IS_PATH) {
@@ -805,10 +806,10 @@ add_special_info (CamelStore *store, CamelFolderInfo *info, const char *name, co
 		camel_url_set_path (url, path);
 		g_free (path);
 	}
-	
+
 	uri = camel_url_to_string (url, CAMEL_URL_HIDE_ALL);
 	camel_url_free (url);
-	
+
 	if (fi) {
 		/* We're going to replace the physical Trash/Junk folder with our vTrash/vJunk folder */
 		vinfo = fi;
@@ -838,9 +839,9 @@ add_special_info (CamelStore *store, CamelFolderInfo *info, const char *name, co
 }
 
 static void
-dump_fi(CamelFolderInfo *fi, int depth)
+dump_fi(CamelFolderInfo *fi, gint depth)
 {
-	char *s;
+	gchar *s;
 
 	s = g_alloca(depth+1);
 	memset(s, ' ', depth);
@@ -875,7 +876,7 @@ dump_fi(CamelFolderInfo *fi, int depth)
  * determine that information quickly.  If @flags includes
  * #CAMEL_STORE_FOLDER_INFO_NO_VIRTUAL, don't include special virtual
  * folders (such as vTrash or vJunk).
- * 
+ *
  * The CAMEL_STORE_FOLDER_INFO_FAST flag should be considered
  * deprecated; most backends will behave the same whether it is
  * supplied or not.  The only guaranteed way to get updated folder
@@ -885,14 +886,14 @@ dump_fi(CamelFolderInfo *fi, int depth)
  * #camel_store_free_folder_info, or %NULL.
  **/
 CamelFolderInfo *
-camel_store_get_folder_info(CamelStore *store, const char *top, guint32 flags, CamelException *ex)
+camel_store_get_folder_info(CamelStore *store, const gchar *top, guint32 flags, CamelException *ex)
 {
 	CamelFolderInfo *info;
-	
+
 	g_return_val_if_fail (CAMEL_IS_STORE (store), NULL);
 
 	info = CS_CLASS (store)->get_folder_info (store, top, flags, ex);
-	
+
 	if (info && (top == NULL || *top == '\0') && (flags & CAMEL_STORE_FOLDER_INFO_NO_VIRTUAL) == 0) {
 		if (info->uri && (store->flags & CAMEL_STORE_VTRASH))
 			/* the name of the Trash folder, used for deleted messages */
@@ -903,13 +904,13 @@ camel_store_get_folder_info(CamelStore *store, const char *top, guint32 flags, C
 	}
 
 	if (camel_debug_start("store:folder_info")) {
-		char *url = camel_url_to_string(((CamelService *)store)->url, CAMEL_URL_HIDE_ALL);
-		printf("Get folder info(%p:%s, '%s') =\n", (void *) store, url, top?top:"<null>");
+		gchar *url = camel_url_to_string(((CamelService *)store)->url, CAMEL_URL_HIDE_ALL);
+		printf("Get folder info(%p:%s, '%s') =\n", (gpointer) store, url, top?top:"<null>");
 		g_free(url);
 		dump_fi(info, 2);
 		camel_debug_end();
 	}
-	
+
 	return info;
 }
 
@@ -996,12 +997,12 @@ camel_folder_info_new (void)
 	return g_slice_new0 (CamelFolderInfo);
 }
 
-static int
-folder_info_cmp (const void *ap, const void *bp)
+static gint
+folder_info_cmp (gconstpointer ap, gconstpointer bp)
 {
 	const CamelFolderInfo *a = ((CamelFolderInfo **)ap)[0];
 	const CamelFolderInfo *b = ((CamelFolderInfo **)bp)[0];
-	
+
 	return strcmp (a->full_name, b->full_name);
 }
 
@@ -1027,27 +1028,27 @@ folder_info_cmp (const void *ap, const void *bp)
  * Returns: the top level of the tree of linked folder info.
  **/
 CamelFolderInfo *
-camel_folder_info_build (GPtrArray *folders, const char *namespace,
-			 char separator, gboolean short_names)
+camel_folder_info_build (GPtrArray *folders, const gchar *namespace,
+			 gchar separator, gboolean short_names)
 {
 	CamelFolderInfo *fi, *pfi, *top = NULL, *tail = NULL;
 	GHashTable *hash;
-	char *p, *pname;
-	int i, nlen;
+	gchar *p, *pname;
+	gint i, nlen;
 
 	if (!namespace)
 		namespace = "";
 	nlen = strlen (namespace);
 
 	qsort (folders->pdata, folders->len, sizeof (folders->pdata[0]), folder_info_cmp);
-	
+
 	/* Hash the folders. */
-	hash = g_hash_table_new (g_str_hash, g_str_equal);
+	hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
 	for (i = 0; i < folders->len; i++) {
 		fi = folders->pdata[i];
-		g_hash_table_insert (hash, fi->full_name, fi);
+		g_hash_table_insert (hash, g_strdup (fi->full_name), fi);
 	}
-	
+
 	/* Now find parents. */
 	for (i = 0; i < folders->len; i++) {
 		fi = folders->pdata[i];
@@ -1060,9 +1061,9 @@ camel_folder_info_build (GPtrArray *folders, const char *namespace,
 			} else {
 				/* we are missing a folder in the heirarchy so
 				   create a fake folder node */
-				const char *path;
+				const gchar *path;
 				CamelURL *url;
-				char *sep;
+				gchar *sep;
 
 				pfi = camel_folder_info_new ();
 				if (short_names) {
@@ -1073,21 +1074,22 @@ camel_folder_info_build (GPtrArray *folders, const char *namespace,
 						pfi->name = g_strdup (pname);
 				} else
 					pfi->name = g_strdup (pname);
-				
+
 				url = camel_url_new (fi->uri, NULL);
 				if (url->fragment)
 					path = url->fragment;
 				else
 					path = url->path + 1;
-				
+
 				sep = strrchr (path, separator);
 				if (sep)
 					*sep = '\0';
-				else
+				else {
 					d(g_warning ("huh, no \"%c\" in \"%s\"?", separator, fi->uri));
-				
+				}
+
 				pfi->full_name = g_strdup (path);
-				
+
 				/* since this is a "fake" folder node, it is not selectable */
 				camel_url_set_param (url, "noselect", "yes");
 				pfi->uri = camel_url_to_string (url, 0);
@@ -1124,7 +1126,7 @@ camel_folder_info_build (GPtrArray *folders, const char *namespace,
 			tail = fi;
 		}
 	}
-	
+
 	return top;
 }
 
@@ -1140,7 +1142,7 @@ folder_info_clone_rec(CamelFolderInfo *fi, CamelFolderInfo *parent)
 	info->full_name = g_strdup(fi->full_name);
 	info->unread = fi->unread;
 	info->flags = fi->flags;
-	
+
 	if (fi->next)
 		info->next = folder_info_clone_rec(fi->next, parent);
 	else
@@ -1154,7 +1156,6 @@ folder_info_clone_rec(CamelFolderInfo *fi, CamelFolderInfo *parent)
 	return info;
 }
 
-
 /**
  * camel_folder_info_clone:
  * @fi: a #CamelFolderInfo
@@ -1172,7 +1173,6 @@ camel_folder_info_clone(CamelFolderInfo *fi)
 	return folder_info_clone_rec(fi, NULL);
 }
 
-
 /**
  * camel_store_supports_subscriptions:
  * @store: a #CamelStore object
@@ -1188,11 +1188,11 @@ camel_store_supports_subscriptions (CamelStore *store)
 }
 
 static gboolean
-folder_subscribed(CamelStore *store, const char *folder_name)
+folder_subscribed(CamelStore *store, const gchar *folder_name)
 {
 	w(g_warning ("CamelStore::folder_subscribed not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
-	
+
 	return FALSE;
 }
 
@@ -1206,7 +1206,7 @@ folder_subscribed(CamelStore *store, const char *folder_name)
  * Returns: %TRUE if the folder has been subscribed to or %FALSE otherwise
  **/
 gboolean
-camel_store_folder_subscribed(CamelStore *store, const char *folder_name)
+camel_store_folder_subscribed(CamelStore *store, const gchar *folder_name)
 {
 	gboolean ret;
 
@@ -1223,7 +1223,7 @@ camel_store_folder_subscribed(CamelStore *store, const char *folder_name)
 }
 
 static void
-subscribe_folder(CamelStore *store, const char *folder_name, CamelException *ex)
+subscribe_folder(CamelStore *store, const gchar *folder_name, CamelException *ex)
 {
 	w(g_warning ("CamelStore::subscribe_folder not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
@@ -1238,7 +1238,7 @@ subscribe_folder(CamelStore *store, const char *folder_name, CamelException *ex)
  * Subscribe to the folder described by @folder_name.
  **/
 void
-camel_store_subscribe_folder(CamelStore *store, const char *folder_name, CamelException *ex)
+camel_store_subscribe_folder(CamelStore *store, const gchar *folder_name, CamelException *ex)
 {
 	g_return_if_fail (CAMEL_IS_STORE (store));
 	g_return_if_fail (store->flags & CAMEL_STORE_SUBSCRIPTIONS);
@@ -1251,13 +1251,12 @@ camel_store_subscribe_folder(CamelStore *store, const char *folder_name, CamelEx
 }
 
 static void
-unsubscribe_folder(CamelStore *store, const char *folder_name, CamelException *ex)
+unsubscribe_folder(CamelStore *store, const gchar *folder_name, CamelException *ex)
 {
 	w(g_warning ("CamelStore::unsubscribe_folder not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
 }
 
-
 /**
  * camel_store_unsubscribe_folder:
  * @store: a #CamelStore object
@@ -1267,7 +1266,7 @@ unsubscribe_folder(CamelStore *store, const char *folder_name, CamelException *e
  * Unsubscribe from the folder described by @folder_name.
  **/
 void
-camel_store_unsubscribe_folder(CamelStore *store, const char *folder_name, CamelException *ex)
+camel_store_unsubscribe_folder(CamelStore *store, const gchar *folder_name, CamelException *ex)
 {
 	CamelException local;
 
@@ -1308,7 +1307,6 @@ camel_store_noop (CamelStore *store, CamelException *ex)
 	CS_CLASS (store)->noop (store, ex);
 }
 
-
 /**
  * camel_store_folder_uri_equal:
  * @store: a #CamelStore object
@@ -1319,29 +1317,29 @@ camel_store_noop (CamelStore *store, CamelException *ex)
  *
  * Returns: %TRUE if they are equal or %FALSE otherwise
  **/
-int
-camel_store_folder_uri_equal (CamelStore *store, const char *uri0, const char *uri1)
+gint
+camel_store_folder_uri_equal (CamelStore *store, const gchar *uri0, const gchar *uri1)
 {
 	CamelProvider *provider;
 	CamelURL *url0, *url1;
-	int equal;
-	
+	gint equal;
+
 	g_return_val_if_fail (CAMEL_IS_STORE (store), FALSE);
 	g_return_val_if_fail (uri0 && uri1, FALSE);
-	
+
 	provider = ((CamelService *) store)->provider;
-	
+
 	if (!(url0 = camel_url_new (uri0, NULL)))
 		return FALSE;
-	
+
 	if (!(url1 = camel_url_new (uri1, NULL))) {
 		camel_url_free (url0);
 		return FALSE;
 	}
-	
+
 	if ((equal = provider->url_equal (url0, url1))) {
-		const char *name0, *name1;
-		
+		const gchar *name0, *name1;
+
 		if (provider->url_flags & CAMEL_URL_FRAGMENT_IS_PATH) {
 			name0 = url0->fragment;
 			name1 = url1->fragment;
@@ -1355,13 +1353,13 @@ camel_store_folder_uri_equal (CamelStore *store, const char *uri0, const char *u
 
 		if (name1 == NULL)
 			g_warning("URI is badly formed, missing folder name: %s", uri1);
-		
+
 		equal = name0 && name1 && CS_CLASS (store)->compare_folder_name (name0, name1);
 	}
-	
+
 	camel_url_free (url0);
 	camel_url_free (url1);
-	
+
 	return equal;
 }
 
@@ -1390,7 +1388,7 @@ camel_store_can_refresh_folder (CamelStore *store, CamelFolderInfo *info, CamelE
 	g_return_val_if_fail (store != NULL, FALSE);
 	g_return_val_if_fail (info != NULL, FALSE);
 
-	return CS_CLASS (store)->can_refresh_folder (store, info, ex);	
+	return CS_CLASS (store)->can_refresh_folder (store, info, ex);
 }
 
 /* subscriptions interface */
@@ -1416,7 +1414,7 @@ CamelType camel_isubscribe_get_type (void)
 	return camel_isubscribe_type;
 }
 
-gboolean camel_isubscribe_subscribed(CamelStore *store, const char *name)
+gboolean camel_isubscribe_subscribed(CamelStore *store, const gchar *name)
 {
 	CamelISubscribe *iface = camel_object_get_interface(store, camel_isubscribe_get_type());
 
@@ -1427,7 +1425,7 @@ gboolean camel_isubscribe_subscribed(CamelStore *store, const char *name)
 	return FALSE;
 }
 
-void camel_isubscribe_subscribe(CamelStore *store, const char *folder_name, CamelException *ex)
+void camel_isubscribe_subscribe(CamelStore *store, const gchar *folder_name, CamelException *ex)
 {
 	CamelISubscribe *iface = camel_object_get_interface(store, camel_isubscribe_get_type());
 
@@ -1439,7 +1437,7 @@ void camel_isubscribe_subscribe(CamelStore *store, const char *folder_name, Came
 	g_warning("Trying to invoke unimplemented subscribe method on a store");
 }
 
-void camel_isubscribe_unsubscribe(CamelStore *store, const char *folder_name, CamelException *ex)
+void camel_isubscribe_unsubscribe(CamelStore *store, const gchar *folder_name, CamelException *ex)
 {
 	CamelISubscribe *iface = camel_object_get_interface(store, camel_isubscribe_get_type());
 
