@@ -42,13 +42,12 @@
 #include "camel-groupwise-store.h"
 #include "camel-groupwise-transport.h"
 
-static void add_hash (guint *hash, char *s);
+static void add_hash (guint *hash, gchar *s);
 static guint groupwise_url_hash (gconstpointer key);
-static gint check_equal (char *s1, char *s2);
+static gint check_equal (gchar *s1, gchar *s2);
 static gint groupwise_url_equal (gconstpointer a, gconstpointer b);
 
-
-CamelProviderConfEntry groupwise_conf_entries[] = {
+static CamelProviderConfEntry groupwise_conf_entries[] = {
 	/* override the labels/defaults of the standard settings */
 
 	{ CAMEL_PROVIDER_CONF_SECTION_START, "mailcheck", NULL,
@@ -77,13 +76,12 @@ CamelProviderConfEntry groupwise_conf_entries[] = {
 
 	{ CAMEL_PROVIDER_CONF_HIDDEN, "auth-domain", NULL,
 	  NULL, "Groupwise" },
-	 	
-	{ CAMEL_PROVIDER_CONF_SECTION_END }, 
+
+	{ CAMEL_PROVIDER_CONF_SECTION_END },
 
 	{ CAMEL_PROVIDER_CONF_END }
 };
 
-
 static CamelProvider groupwise_provider = {
 	"groupwise",
 	N_("Novell GroupWise"),
@@ -104,15 +102,15 @@ static CamelProvider groupwise_provider = {
 
 CamelServiceAuthType camel_groupwise_password_authtype = {
 	N_("Password"),
-	
+
 	N_("This option will connect to the GroupWise server using a "
 	   "plaintext password."),
-	
+
 	"",
 	TRUE
 };
 
-static int
+static gint
 groupwise_auto_detect_cb (CamelURL *url, GHashTable **auto_detected,
 			 CamelException *ex)
 {
@@ -139,20 +137,19 @@ camel_provider_module_init(void)
 	groupwise_provider.auto_detect = groupwise_auto_detect_cb;
 	groupwise_provider.authtypes = g_list_prepend (groupwise_provider.authtypes, &camel_groupwise_password_authtype);
 	groupwise_provider.translation_domain = GETTEXT_PACKAGE;
-	
+
 	if (use_imap)
 		groupwise_provider.object_types[CAMEL_PROVIDER_STORE] = imap_provider->object_types [CAMEL_PROVIDER_STORE];
-	else 	{
+	else	{
 		groupwise_provider.object_types[CAMEL_PROVIDER_STORE] =  camel_groupwise_store_get_type();
 		groupwise_provider.object_types[CAMEL_PROVIDER_TRANSPORT] = camel_groupwise_transport_get_type();
-	} 
-	
+	}
+
 	camel_provider_register (&groupwise_provider);
 }
 
-
 static void
-add_hash (guint *hash, char *s)
+add_hash (guint *hash, gchar *s)
 {
 	if (s)
 		*hash ^= g_str_hash(s);
@@ -167,12 +164,12 @@ groupwise_url_hash (gconstpointer key)
 	add_hash (&hash, u->user);
 	add_hash (&hash, u->host);
 	hash ^= u->port;
-	
+
 	return hash;
 }
 
 static gint
-check_equal (char *s1, char *s2)
+check_equal (gchar *s1, gchar *s2)
 {
 	if (s1 == NULL) {
 		if (s2 == NULL)
@@ -180,7 +177,7 @@ check_equal (char *s1, char *s2)
 		else
 			return FALSE;
 	}
-	
+
 	if (s2 == NULL)
 		return FALSE;
 
@@ -191,7 +188,7 @@ static gint
 groupwise_url_equal (gconstpointer a, gconstpointer b)
 {
 	const CamelURL *u1 = a, *u2 = b;
-	
+
 	return check_equal (u1->protocol, u2->protocol)
 		&& check_equal (u1->user, u2->user)
 		&& check_equal (u1->host, u2->host)
