@@ -177,7 +177,7 @@ find_folders_recursive (const gchar *physical_path, const gchar *path,
 		file_path = g_strdup_printf ("%s/%s", subfolder_directory_path, dirent);
 
 		if (g_stat (file_path, &file_stat) < 0 ||
-		    ! S_ISDIR (file_stat.st_mode)) {
+		    !S_ISDIR (file_stat.st_mode)) {
 			g_free (file_path);
 			continue;
 		}
@@ -270,7 +270,7 @@ add_recipients(GSList *recipient_list, CamelAddress *recipients, gint recipient_
 	total_add = camel_address_length (recipients);
 	for (i=0; i<total_add; i++) {
 		const gchar *name = NULL, *addr = NULL;
-		if(camel_internet_address_get ((CamelInternetAddress *)recipients, i , &name, &addr )) {
+		if (camel_internet_address_get ((CamelInternetAddress *)recipients, i , &name, &addr )) {
 
 			recipient = g_new0 (EGwItemRecipient, 1);
 
@@ -308,7 +308,6 @@ send_as_attachment (EGwConnection *cnc, EGwItem *item, CamelStreamMem *content,
 			attachment->size = temp_len;
 			g_free (temp_str);
 			temp_str = NULL;
-			temp_len = 0;
 		} else {
 			attachment->data = g_base64_encode(content->buffer->data, content->buffer->len);
 			attachment->size = strlen (attachment->data);
@@ -325,7 +324,6 @@ send_as_attachment (EGwConnection *cnc, EGwItem *item, CamelStreamMem *content,
 			attachment->size = temp_len;
 			g_free (temp_str);
 			temp_str = NULL;
-			temp_len = 0;
 		}
 	}
 
@@ -341,28 +339,27 @@ send_as_attachment (EGwConnection *cnc, EGwItem *item, CamelStreamMem *content,
 
 	attachment->name = g_strdup (filename ? filename : "");
 	if (camel_content_type_is (type, "message", "rfc822")) {
-		const gchar *item_id;
-		gchar *msgid;
-		gint len;
+		gchar *item_id;
 
-		item_id = camel_medium_get_header (CAMEL_MEDIUM (dw), "X-GW-ITEM-ID");
+		item_id = g_strdup (camel_medium_get_header (CAMEL_MEDIUM (dw), "X-GW-ITEM-ID"));
 		/*
 		 * XXX: The following code piece is a screwed up way of doing stuff.
 		 * But we dont have much choice. Do not use 'camel_header_msgid_decode'
 		 * since it removes the container id portion from the id and which the
 		 * groupwise server needs.
 		 */
-
-		len = strlen (item_id);
-		msgid = (gchar *)g_malloc0 (len-1);
-		msgid = memcpy(msgid, item_id+2, len-3);
-		g_print ("||| msgid:%s\n", msgid);
-
-		status = e_gw_connection_forward_item (cnc, msgid, NULL, TRUE, &temp_item);
-		g_free (msgid);
+		g_strstrip (item_id);
+		status = e_gw_connection_forward_item (cnc, item_id, NULL, TRUE, &temp_item);
+		g_free (item_id);
 
 		if (status != E_GW_CONNECTION_STATUS_OK) {
 			g_warning ("Could not send a forwardRequest...continuing without!!\n");
+
+			g_free (attachment->name);
+			attachment->name = g_strdup ("Mime.822");
+
+			g_free (attachment->contentType);
+			attachment->contentType = g_strdup ("Mail");
 		} else {
 			GSList *attach_list = e_gw_item_get_attach_id_list (temp_item);
 			EGwItemAttachment *temp_attach = (EGwItemAttachment *)attach_list->data;
@@ -410,7 +407,7 @@ camel_groupwise_util_item_from_message (EGwConnection *cnc, CamelMimeMessage *me
 
 	/** Get the mime parts from CamelMimemessge **/
 	mp = (CamelMultipart *)camel_medium_get_content_object (CAMEL_MEDIUM (message));
-	if(!mp) {
+	if (!mp) {
 		g_warning ("ERROR: Could not get content object");
 		camel_operation_end (NULL);
 		return NULL;
