@@ -27,6 +27,7 @@
 #include <config.h>
 #endif
 
+#include <string.h>
 #include "camel/camel-provider.h"
 #include "camel/camel-session.h"
 #include "camel/camel-url.h"
@@ -35,11 +36,14 @@
 
 #include "camel-imapx-store.h"
 
+static guint imapx_url_hash (gconstpointer key);
+static gint  imapx_url_equal (gconstpointer a, gconstpointer b);
+
 CamelProviderConfEntry imapx_conf_entries[] = {
 		{ CAMEL_PROVIDER_CONF_SECTION_START, "mailcheck", NULL,
 	  N_("Checking for New Mail") },
 	{ CAMEL_PROVIDER_CONF_CHECKBOX, "use_idle", NULL,
-	  N_("Use Idle if the server supports it"), "1" },
+	  N_("Use I_dle if the server supports it"), "1" },
 	{ CAMEL_PROVIDER_CONF_CHECKBOX, "check_all", NULL,
 	  N_("C_heck for new messages in all folders"), "1" },
 	{ CAMEL_PROVIDER_CONF_CHECKBOX, "check_lsub", NULL,
@@ -52,8 +56,8 @@ CamelProviderConfEntry imapx_conf_entries[] = {
 	  N_("_Use custom command to connect to server"), "0" },
 	{ CAMEL_PROVIDER_CONF_ENTRY, "command", "use_command",
 	  N_("Command:"), "ssh -C -l %u %h exec /usr/sbin/imapd" },
-	{ CAMEL_PROVIDER_CONF_CHECKSPIN, "cached_conn", NULL,
-	  N_("Number of _cached connections to use"), "y:1:5:7" },
+	{ CAMEL_PROVIDER_CONF_CHECKSPIN, "cachedconn", NULL,
+	  N_("Numbe_r of cached connections to use"), "y:1:5:7" },
 	{ CAMEL_PROVIDER_CONF_SECTION_END },
 #endif
 	{ CAMEL_PROVIDER_CONF_SECTION_START, "folders", NULL,
@@ -115,8 +119,8 @@ void
 camel_imapx_module_init(void)
 {
 	imapx_provider.object_types[CAMEL_PROVIDER_STORE] = camel_imapx_store_get_type();
-	imapx_provider.url_hash = camel_url_hash;
-	imapx_provider.url_equal = camel_url_equal;
+	imapx_provider.url_hash = imapx_url_hash;
+	imapx_provider.url_equal = imapx_url_equal;
 	imapx_provider.authtypes = camel_sasl_authtype_list(FALSE);
 	imapx_provider.authtypes = g_list_prepend(imapx_provider.authtypes, &camel_imapx_password_authtype);
 	imapx_provider.translation_domain = GETTEXT_PACKAGE;
@@ -133,3 +137,50 @@ camel_provider_module_init(void)
 {
 	camel_imapx_module_init();
 }
+
+static void
+imapx_add_hash (guint *hash, gchar *s)
+{
+	if (s)
+		*hash ^= g_str_hash(s);
+}
+
+static guint
+imapx_url_hash (gconstpointer key)
+{
+	const CamelURL *u = (CamelURL *)key;
+	guint hash = 0;
+
+	imapx_add_hash (&hash, u->user);
+	imapx_add_hash (&hash, u->host);
+	hash ^= u->port;
+
+	return hash;
+}
+
+static gint
+imapx_check_equal (gchar *s1, gchar *s2)
+{
+	if (s1 == NULL) {
+		if (s2 == NULL)
+			return TRUE;
+		else
+			return FALSE;
+	}
+
+	if (s2 == NULL)
+		return FALSE;
+
+	return strcmp (s1, s2) == 0;
+}
+
+static gint
+imapx_url_equal (gconstpointer a, gconstpointer b)
+{
+	const CamelURL *u1 = a, *u2 = b;
+
+	return imapx_check_equal (u1->protocol, u2->protocol)
+		&& imapx_check_equal (u1->user, u2->user)
+		&& imapx_check_equal (u1->host, u2->host)
+		&& u1->port == u2->port;
+}
