@@ -4,7 +4,7 @@
  *  Ebby Wiselyn <ebbywiselyn@gmail.com>
  *  Jason Willis <zenbrother@gmail.com>
  *
- * Copyright 2007, Novell, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -32,13 +32,13 @@ gdata_service_set_proxy (GDataService *self, SoupURI *proxy)
 }
 
 void
-gdata_service_set_credentials (GDataService *self, const char *username, const gchar *password)
+gdata_service_set_credentials (GDataService *self, const gchar *username, const gchar *password)
 {
 	GDATA_SERVICE_GET_IFACE(self)->set_credentials(self, username, password);
 }
 
 GDataFeed*
-gdata_service_get_feed (GDataService *self, const char* feedURL, GError **error)
+gdata_service_get_feed (GDataService *self, const gchar * feedURL, GError **error)
 {
 	return GDATA_SERVICE_GET_IFACE(self)->get_feed(self, feedURL, error);
 }
@@ -87,10 +87,9 @@ gdata_service_base_init (gpointer g_class)
 GType
 gdata_service_get_type (void)
 {
-	static GType type = 0;
+        static volatile gsize define_type_id__volatile = 0;
 
-	if (G_UNLIKELY(type == 0))
-	{
+	if (g_once_init_enter (&define_type_id__volatile)) {
 		static const GTypeInfo info =
 		{
 			sizeof (GDataServiceIface),
@@ -103,10 +102,12 @@ gdata_service_get_type (void)
 			0,      /* n_preallocs */
 			NULL    /* instance_init */
 		};
-		type = g_type_register_static (G_TYPE_INTERFACE,
-				"GDataService", &info, 0);
-		g_type_interface_add_prerequisite (type, G_TYPE_OBJECT );
+		GType type = g_type_register_static (G_TYPE_INTERFACE, "GDataService", &info, 0);
+
+		g_type_interface_add_prerequisite (type, G_TYPE_OBJECT);
+
+		g_once_init_leave (&define_type_id__volatile, type);
 	}
 
-	return type;
+	return define_type_id__volatile;
 }
